"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MockXMLHttpRequest_1 = require("./MockXMLHttpRequest");
const window = require("global");
const real = window.XMLHttpRequest;
class Builder {
    constructor() {
        this.XMLHttpRequest = new MockXMLHttpRequest_1.default();
    }
    /** Replace the native XHR with the mocked XHR */
    setup() {
        window.XMLHttpRequest = MockXMLHttpRequest_1.default;
        return this.reset();
    }
    /** Replace the mocked XHR with the native XHR and remove any handlers */
    teardown() {
        window.XMLHttpRequest = real;
        return this.reset();
    }
    /** Remove any handlers */
    reset() {
        MockXMLHttpRequest_1.default.reset();
        return this;
    }
    mock(method, url, fn) {
        let handler;
        if (typeof url !== "undefined") {
            const matcher = (req) => {
                if (req.method() !== method) {
                    return false;
                }
                const reqUrl = req.url();
                if (url instanceof RegExp) {
                    return url.test(reqUrl);
                }
                // otherwise assume the url is a string
                return url === reqUrl;
            };
            handler = (req, res) => {
                if (matcher(req)) {
                    return fn(req, res);
                }
                return false;
            };
        }
        else {
            handler = method;
        }
        MockXMLHttpRequest_1.default.addHandler(handler);
        return this;
    }
    /** Mock a GET request */
    get(url, fn) {
        return this.mock("GET", url, fn);
    }
    /** Mock a POST request */
    post(url, fn) {
        return this.mock("POST", url, fn);
    }
    /** Mock a PUT request */
    put(url, fn) {
        return this.mock("PUT", url, fn);
    }
    /** Mock a PATCH request */
    patch(url, fn) {
        return this.mock("PATCH", url, fn);
    }
    /** Mock a DELETE request */
    delete(url, fn) {
        return this.mock("DELETE", url, fn);
    }
}
exports.Builder = Builder;
exports.default = new Builder();
//# sourceMappingURL=Builder.js.map