"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** The mocked response data */
class MockResponse {
    constructor() {
        this._status = 200;
        this._headers = {};
        this._body = "";
        this._timeout = 0;
    }
    status(code) {
        if (typeof code === "undefined") {
            return this._status;
        }
        this._status = code;
        return this;
    }
    header(name, value) {
        if (typeof value === "undefined") {
            return this._headers[name.toLowerCase()] || null;
        }
        this._headers[name.toLowerCase()] = value;
        return this;
    }
    headers(headers) {
        if (typeof headers === "undefined") {
            return this._headers;
        }
        Object.keys(headers).forEach(key => this.header(key, headers[key]));
        return this;
    }
    body(body) {
        if (typeof body === "undefined") {
            return this._body;
        }
        if (typeof body === "object") {
            body = JSON.stringify(body);
        }
        this._body = body;
        return this;
    }
    timeout(timeout) {
        if (typeof timeout === "undefined") {
            return this._timeout;
        }
        this._timeout = typeof timeout === "number"
            ? timeout
            : 1;
        return this;
    }
}
exports.default = MockResponse;
//# sourceMappingURL=MockResponse.js.map