import MockXMLHttpRequest from "./MockXMLHttpRequest";
import * as window from "global";
const real = window.XMLHttpRequest;
export class Builder {
    constructor() {
        this.XMLHttpRequest = new MockXMLHttpRequest();
    }
    /** Replace the native XHR with the mocked XHR */
    setup() {
        window.XMLHttpRequest = MockXMLHttpRequest;
        return this.reset();
    }
    /** Replace the mocked XHR with the native XHR and remove any handlers */
    teardown() {
        window.XMLHttpRequest = real;
        return this.reset();
    }
    /** Remove any handlers */
    reset() {
        MockXMLHttpRequest.reset();
        return this;
    }
    mock(method, url, fn) {
        let handler;
        if (typeof url !== "undefined") {
            const matcher = (req) => {
                if (req.method() !== method) {
                    return false;
                }
                const reqUrl = req.url();
                if (url instanceof RegExp) {
                    return url.test(reqUrl);
                }
                // otherwise assume the url is a string
                return url === reqUrl;
            };
            handler = (req, res) => {
                if (matcher(req)) {
                    return fn(req, res);
                }
                return false;
            };
        }
        else {
            handler = method;
        }
        MockXMLHttpRequest.addHandler(handler);
        return this;
    }
    /** Mock a GET request */
    get(url, fn) {
        return this.mock("GET", url, fn);
    }
    /** Mock a POST request */
    post(url, fn) {
        return this.mock("POST", url, fn);
    }
    /** Mock a PUT request */
    put(url, fn) {
        return this.mock("PUT", url, fn);
    }
    /** Mock a PATCH request */
    patch(url, fn) {
        return this.mock("PATCH", url, fn);
    }
    /** Mock a DELETE request */
    delete(url, fn) {
        return this.mock("DELETE", url, fn);
    }
}
export default new Builder();
//# sourceMappingURL=Builder.js.map