import * as URL from "url";
import MockProgressEvent from "./polyfill/MockProgressEvent";
/** The mocked request data */
export default class MockRequest {
    constructor(xhr) {
        this._xhr = xhr;
        this._method = xhr.method;
        this._url = xhr.url;
        this._headers = {};
        this.headers(xhr._requestHeaders);
        this.body(xhr.data);
    }
    /** Get the HTTP method */
    method() {
        return this._method;
    }
    /** Get the HTTP URL */
    url() {
        return this._url;
    }
    /** Get the parsed URL query */
    query() {
        const parsed = URL.parse(this._url, true).query;
        Object.keys(parsed).forEach(key => {
            if (!isNaN(parsed[key])) {
                parsed[key] = Number(parsed[key]);
            }
        });
        return parsed;
    }
    header(name, value) {
        if (typeof value === "undefined") {
            return this._headers[name.toLowerCase()] || null;
        }
        this._headers[name.toLowerCase()] = value;
        return this;
    }
    headers(headers) {
        if (typeof headers === "undefined") {
            return this._headers;
        }
        Object.keys(headers).forEach(key => this.header(key, headers[key]));
        return this;
    }
    body(body) {
        if (typeof body === "undefined") {
            return this._body;
        }
        this._body = body;
        return this;
    }
    /** Trigger progress event */
    progress(loaded, total, lengthComputable) {
        const evt = new MockProgressEvent("progress", {
            lengthComputable: lengthComputable || true,
            loaded,
            total,
        });
        this._xhr.upload.dispatchEvent(evt);
        this._xhr.trigger("progress", evt);
    }
}
//# sourceMappingURL=MockRequest.js.map